@@ -4,11 +4,12 @@ package Mail::AuthenticationResults::Header::Base;
 require 5.008;
 use strict;
 use warnings;
-our $VERSION = '1.20180314'; # VERSION
+our $VERSION = '1.20180328'; # VERSION
 use Scalar::Util qw{ weaken refaddr };
 use Carp;
 
 use Mail::AuthenticationResults::Header::Group;
+use Mail::AuthenticationResults::FoldableHeader;
 
 
 sub _HAS_KEY{ return 0; }
@@ -201,7 +202,7 @@ sub ancestor {
 
 
 sub as_string_prefix {
-    my ( $self ) = @_;
+    my ( $self, $header ) = @_;
 
     my ( $eldest, $depth ) = $self->ancestor();
 
@@ -216,11 +217,15 @@ sub as_string_prefix {
     }
 
     my $indent = ' ';
+    my $added = 0;
     if ( $eldest->can( 'indent_on' ) ) {
         if ( $eldest->indent_on( ref $self ) ) {
-            $indent = $eol . ' ' x ( $indents * $depth );
+            $header->space( $eol );
+            $header->space( ' ' x ( $indents * $depth ) );
+            $added = 1;
         }
     }
+    $header->space( ' ' ) if ! $added;
 
     return $indent;
 }
@@ -228,32 +233,43 @@ sub as_string_prefix {
 
 sub as_string {
     my ( $self ) = @_;
+    my $header = Mail::AuthenticationResults::FoldableHeader->new();
+    $self->build_string( $header );
+    return $header->as_string();
+}
+
+
+sub build_string {
+    my ( $self, $header ) = @_;
 
     if ( ! $self->key() ) {
-        return q{};
+        return;
     }
 
-    my $string = $self->stringify( $self->key() );
+    $header->string( $self->stringify( $self->key() ) );
     if ( $self->value() ) {
-        $string .= '=' . $self->stringify( $self->value() );
+        $header->assignment( '=' );
+        $header->string( $self->stringify( $self->value() ) );
     }
     elsif ( $self->value() eq '0' ) {
-        $string .= '=0';
+        $header->assignment( '=' );
+        $header->string( '0' );
     }
     elsif ( $self->value() eq q{} ) {
         # special case none here
         if ( $self->key() ne 'none' ) {
-            $string .= '=""';
+            $header->assignment( '=' );
+            $header->string( '""' );
         }
     }
     if ( $self->_HAS_CHILDREN() ) { # uncoverable branch false
         # There are no classes which run this code without having children
         foreach my $child ( @{$self->children()} ) {
-            $string .= $child->as_string_prefix();
-            $string .= $child->as_string();
+            $child->as_string_prefix( $header );
+            $child->build_string( $header );
         }
     }
-    return $string;
+    return;
 }
 
 
@@ -340,7 +356,7 @@ Mail::AuthenticationResults::Header::Base - Base class for modelling parts of th
 
 =head1 VERSION
 
-version 1.20180314
+version 1.20180328
 
 =head1 DESCRIPTION
 
@@ -456,15 +472,19 @@ Croaks if the relationship between $child and $self is not valid.
 
 Returns the top Header object and depth of this child
 
-=head2 as_string_prefix()
+=head2 as_string_prefix( $header )
 
-Return the prefix to as_string for this object when calledas a child
+Add the prefix to as_string for this object when calledas a child
 of another objects as_string method call.
 
 =head2 as_string()
 
 Returns this instance as a string.
 
+=head2 build_string( $header )
+
+Build a string using the supplied Mail::AuthenticationResults::FoldableHeader object.
+
 =head2 search( $search )
 
 Apply search rules in $search to this instance and return a
