@@ -4,7 +4,7 @@ package Mail::AuthenticationResults::Header::Group;
 require 5.008;
 use strict;
 use warnings;
-our $VERSION = '1.20180314'; # VERSION
+our $VERSION = '1.20180328'; # VERSION
 use Scalar::Util qw{ refaddr };
 use Carp;
 
@@ -48,10 +48,18 @@ sub add_child {
     return $child;
 }
 
-sub as_string {
-    my ( $self ) = @_;
-    my $string = q{};
-    return join( ";\n", map { $_->as_string() } @{ $self->children() } );
+sub build_string {
+    my ( $self, $header ) = @_;
+
+    my $sep = 0;
+    foreach my $child ( @{ $self->children() } ) {
+        $header->separator( ';' ) if $sep;
+        $header->space( "\n" ) if $sep;
+        $sep = 1;
+        $child->build_string( $header );
+    }
+
+    return;
 }
 
 1;
@@ -68,7 +76,7 @@ Mail::AuthenticationResults::Header::Group - Class modelling Groups of Authentic
 
 =head1 VERSION
 
-version 1.20180314
+version 1.20180328
 
 =head1 DESCRIPTION
 
